==> Agi4x44PreProcess_1.12.0.zip: Agi4x44PreProcess/doc/Agi4x44PreProcess.R <==
###################################################
### chunk number 1: 
###################################################
#line 61 "Agi4x44PreProcess.Rnw"
library("hgug4112a.db")


###################################################
### chunk number 2: data
###################################################
#line 110 "Agi4x44PreProcess.Rnw"
library("Agi4x44PreProcess")
data(targets)
targets


###################################################
### chunk number 3: data
###################################################
#line 180 "Agi4x44PreProcess.Rnw"
data(dd) 
class(dd)
dim(dd)


###################################################
### chunk number 4: 
###################################################
#line 188 "Agi4x44PreProcess.Rnw"
names(dd)


###################################################
### chunk number 5: BoxPlot1
###################################################
#line 284 "Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$R),"ProcessedSignal", "red",
xlab="Samples", ylab="expression")


###################################################
### chunk number 6: plotDensity1
###################################################
#line 291 "Agi4x44PreProcess.Rnw"
plotDensity(log2(dd$R),"ProcessedSignal")


###################################################
### chunk number 7: BoxPlot2
###################################################
#line 297 "Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$G),"MeanSignal", "green",
xlab="Samples", ylab="expression")


###################################################
### chunk number 8: plotDensity2
###################################################
#line 304 "Agi4x44PreProcess.Rnw"
plotDensity(log2(dd$G),"MeanSignal")


###################################################
### chunk number 9: BoxPlot3
###################################################
#line 310 "Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$Gb),"BGUsed", "orange",
xlab="Samples", ylab="expression")


###################################################
### chunk number 10: BoxPlot4
###################################################
#line 317 "Agi4x44PreProcess.Rnw"
BoxPlot(log2(dd$Rb),"BGMedianSignal", "blue",
xlab="Samples", ylab="expression")


###################################################
### chunk number 11: CV.rep.probes
###################################################
#line 350 "Agi4x44PreProcess.Rnw"
CV.rep.probes(dd,"hgug4112a.db",
               	foreground="MeanSignal", raw.data=TRUE,
		writeR=FALSE, targets)


###################################################
### chunk number 12: genes.rpt.agi
###################################################
#line 381 "Agi4x44PreProcess.Rnw"
genes.rpt.agi(dd,"hgug4112a.db",raw.data=TRUE,
               WRITE.html=FALSE,REPORT=FALSE)


###################################################
### chunk number 13: BGandNorm
###################################################
#line 456 "Agi4x44PreProcess.Rnw"
ddNORM=BGandNorm(dd,BGmethod="half",NORMmethod="quantile",
                 foreground="MeanSignal",background="BGMedianSignal",
                 offset=50,makePLOTpre=FALSE,makePLOTpost=FALSE)


###################################################
### chunk number 14: filter.probes
###################################################
#line 593 "Agi4x44PreProcess.Rnw"
ddFILT=filter.probes(ddNORM,
                control=TRUE,
                wellaboveBG=TRUE,
                isfound=TRUE,
                wellaboveNEG=TRUE,
                sat=TRUE,
                PopnOL=TRUE,
                NonUnifOL=T,
                nas=TRUE,
                limWellAbove=75,
                limISF=75,
                limNEG=75,
                limSAT=75,
                limPopnOL=75,
                limNonUnifOL=75,
                limNAS=100,
                makePLOT=F,annotation.package="hgug4112a.db",flag.counts=T,targets)


###################################################
### chunk number 15: 
###################################################
#line 613 "Agi4x44PreProcess.Rnw"
dim(ddFILT)


###################################################
### chunk number 16: summarize.probe
###################################################
#line 655 "Agi4x44PreProcess.Rnw"
ddPROC=summarize.probe(ddFILT, makePLOT=FALSE, targets)


###################################################
### chunk number 17: build.eset
###################################################
#line 670 "Agi4x44PreProcess.Rnw"
esetPROC=build.eset(ddPROC, targets, makePLOT=FALSE,
                annotation.package="hgug4112a.db")


###################################################
### chunk number 18: BoxPlot eval=FALSE
###################################################
## #line 744 "Agi4x44PreProcess.Rnw"
## BoxPlot(log2(dd$G),"MeanSignal","green",
## xlab="Samples",ylab="expression")


###################################################
### chunk number 19: boxplotNegCtrl
###################################################
#line 753 "Agi4x44PreProcess.Rnw"
boxplotNegCtrl(dd,Log2=FALSE, channel="G")


###################################################
### chunk number 20: plotDensity eval=FALSE
###################################################
## #line 774 "Agi4x44PreProcess.Rnw"
## plotDensity(log2(dd$G),"Density Plot example")


###################################################
### chunk number 21: MVAplotMEDctrl eval=FALSE
###################################################
## #line 794 "Agi4x44PreProcess.Rnw"
## 
## par(mfrow=c(2,2),ask=TRUE)	
## MVAplotMEDctrl(dd,"MVA example",channel="G")


###################################################
### chunk number 22: MVAplotMED eval=FALSE
###################################################
## #line 809 "Agi4x44PreProcess.Rnw"
## par(mfrow=c(2,2))
## MVAplotMED(dd$G,"red","MVA example")


###################################################
### chunk number 23: RLE
###################################################
#line 828 "Agi4x44PreProcess.Rnw"
par(mfrow=c(1,1))	
RLE(log2(dd$G),"RLE example ","orange")



###################################################
### chunk number 24: HeatMap
###################################################
#line 845 "Agi4x44PreProcess.Rnw"
HeatMap(exprs(esetPROC),size=100,"100 High Var genes")


###################################################
### chunk number 25: hierclus
###################################################
#line 860 "Agi4x44PreProcess.Rnw"

data(targets)
GErep=targets$Gerep 
hierclus(exprs(esetPROC),GErep,methdis="euclidean",
        methclu="complete",sel=FALSE,size = 100)



###################################################
### chunk number 26: PCAplot eval=FALSE
###################################################
## #line 878 "Agi4x44PreProcess.Rnw"
## 
## data(targets)
## PCAplot(esetPROC,targets)

==> Agi4x44PreProcess_1.20.0.zip: Agi4x44PreProcess/doc/Agi4x44PreProcess.R <==
### R code from vignette source 'Agi4x44PreProcess.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: Agi4x44PreProcess.Rnw:60-61
###################################################
library("hgug4112a.db")


###################################################
### code chunk number 2: data
###################################################
library("Agi4x44PreProcess")
data(targets)
targets


###################################################
### code chunk number 3: data
###################################################
data(dd) 
class(dd)
dim(dd)


###################################################
### code chunk number 4: Agi4x44PreProcess.Rnw:187-188
###################################################
names(dd)


###################################################
### code chunk number 5: BoxPlot1
###################################################
BoxPlot(log2(dd$R),"ProcessedSignal", "red",
xlab="Samples", ylab="expression")


###################################################
### code chunk number 6: plotDensity1
###################################################
plotDensity(log2(dd$R),"ProcessedSignal")


###################################################
### code chunk number 7: BoxPlot2
###################################################
BoxPlot(log2(dd$G),"MeanSignal", "green",
xlab="Samples", ylab="expression")


###################################################
### code chunk number 8: plotDensity2
###################################################
plotDensity(log2(dd$G),"MeanSignal")


###################################################
### code chunk number 9: BoxPlot3
###################################################
BoxPlot(log2(dd$Gb),"BGUsed", "orange",
xlab="Samples", ylab="expression")


###################################################
### code chunk number 10: BoxPlot4
###################################################
BoxPlot(log2(dd$Rb),"BGMedianSignal", "blue",
xlab="Samples", ylab="expression")


###################################################
### code chunk number 11: CV.rep.probes
###################################################
CV.rep.probes(dd,"hgug4112a.db",
               	foreground="MeanSignal", raw.data=TRUE,
		writeR=FALSE, targets)


###################################################
### code chunk number 12: genes.rpt.agi
###################################################
genes.rpt.agi(dd,"hgug4112a.db",raw.data=TRUE,
               WRITE.html=FALSE,REPORT=FALSE)


###################################################
### code chunk number 13: BGandNorm
###################################################
ddNORM=BGandNorm(dd,BGmethod="half",NORMmethod="quantile",
                 foreground="MeanSignal",background="BGMedianSignal",
                 offset=50,makePLOTpre=FALSE,makePLOTpost=FALSE)


###################################################
### code chunk number 14: filter.probes
###################################################
ddFILT=filter.probes(ddNORM,
                control=TRUE,
                wellaboveBG=TRUE,
                isfound=TRUE,
                wellaboveNEG=TRUE,
                sat=TRUE,
                PopnOL=TRUE,
                NonUnifOL=T,
                nas=TRUE,
                limWellAbove=75,
                limISF=75,
                limNEG=75,
                limSAT=75,
                limPopnOL=75,
                limNonUnifOL=75,
                limNAS=100,
                makePLOT=F,annotation.package="hgug4112a.db",flag.counts=T,targets)


###################################################
### code chunk number 15: Agi4x44PreProcess.Rnw:612-613
###################################################
dim(ddFILT)


###################################################
### code chunk number 16: summarize.probe
###################################################
ddPROC=summarize.probe(ddFILT, makePLOT=FALSE, targets)


###################################################
### code chunk number 17: build.eset
###################################################
esetPROC=build.eset(ddPROC, targets, makePLOT=FALSE,
                annotation.package="hgug4112a.db")


###################################################
### code chunk number 18: BoxPlot (eval = FALSE)
###################################################
## BoxPlot(log2(dd$G),"MeanSignal","green",
## xlab="Samples",ylab="expression")


###################################################
### code chunk number 19: boxplotNegCtrl
###################################################
boxplotNegCtrl(dd,Log2=FALSE, channel="G")


###################################################
### code chunk number 20: plotDensity (eval = FALSE)
###################################################
## plotDensity(log2(dd$G),"Density Plot example")


###################################################
### code chunk number 21: MVAplotMEDctrl (eval = FALSE)
###################################################
## 
## par(mfrow=c(2,2),ask=TRUE)	
## MVAplotMEDctrl(dd,"MVA example",channel="G")


###################################################
### code chunk number 22: MVAplotMED (eval = FALSE)
###################################################
## par(mfrow=c(2,2))
## MVAplotMED(dd$G,"red","MVA example")


###################################################
### code chunk number 23: RLE
###################################################
par(mfrow=c(1,1))	
RLE(log2(dd$G),"RLE example ","orange")



###################################################
### code chunk number 24: HeatMap
###################################################
HeatMap(exprs(esetPROC),size=100,"100 High Var genes")


###################################################
### code chunk number 25: hierclus
###################################################

data(targets)
GErep=targets$Gerep 
hierclus(exprs(esetPROC),GErep,methdis="euclidean",
        methclu="complete",sel=FALSE,size = 100)



###################################################
### code chunk number 26: PCAplot (eval = FALSE)
###################################################
## 
## data(targets)
## PCAplot(esetPROC,targets)
